@@ -217,6 +217,7 @@ PyAPI_FUNC(PyObject *) PyLong_FromLongLong(Signed arg0);
 PyAPI_FUNC(PyObject *) PyLong_FromSize_t(Unsigned arg0);
 PyAPI_FUNC(PyObject *) PyLong_FromSsize_t(Py_ssize_t arg0);
 PyAPI_FUNC(PyObject *) PyLong_FromString(const char *arg0, char **arg1, int arg2);
+PyAPI_FUNC(PyObject *) PyLong_FromUnicode(wchar_t *arg0, Py_ssize_t arg1, int arg2);
 PyAPI_FUNC(PyObject *) PyLong_FromUnsignedLong(Unsigned arg0);
 PyAPI_FUNC(PyObject *) PyLong_FromUnsignedLongLong(Unsigned arg0);
 PyAPI_FUNC(PyObject *) PyLong_FromVoidPtr(void *arg0);
@@ -281,6 +282,7 @@ PyAPI_FUNC(PyObject *) PyNumber_Rshift(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(PyObject *) PyNumber_Subtract(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(PyObject *) PyNumber_TrueDivide(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(PyObject *) PyNumber_Xor(PyObject *arg0, PyObject *arg1);
+PyAPI_FUNC(char *) PyOS_double_to_string(double arg0, char arg1, int arg2, int arg3, int *arg4);
 PyAPI_FUNC(double) PyOS_string_to_double(char *arg0, char **arg1, PyObject *arg2);
 PyAPI_FUNC(int) PyObject_AsCharBuffer(PyObject *arg0, char **arg1, Py_ssize_t *arg2);
 PyAPI_FUNC(int) PyObject_AsFileDescriptor(PyObject *arg0);
