@@ -117,6 +117,7 @@
 #define PyLong_FromDouble PyPyLong_FromDouble
 #define PyLong_AsDouble PyPyLong_AsDouble
 #define PyLong_FromString PyPyLong_FromString
+#define PyLong_FromUnicode PyPyLong_FromUnicode
 #define PyLong_FromVoidPtr PyPyLong_FromVoidPtr
 #define PyLong_AsVoidPtr PyPyLong_AsVoidPtr
 #define _PyLong_NumBits _PyPyLong_NumBits
@@ -516,6 +517,7 @@
 #define PyFile_Name PyPyFile_Name
 #define PyFile_SoftSpace PyPyFile_SoftSpace
 #define PyOS_string_to_double PyPyOS_string_to_double
+#define PyOS_double_to_string PyPyOS_double_to_string
 #define Py_FatalError PyPy_FatalError
 #define PyOS_snprintf PyPyOS_snprintf
 #define PyOS_vsnprintf PyPyOS_vsnprintf
@@ -600,6 +602,7 @@
 #define PyThread_ReInitTLS PyPyThread_ReInitTLS
 #define PyStructSequence_InitType PyPyStructSequence_InitType
 #define PyStructSequence_New PyPyStructSequence_New
+#define PyStructSequence_UnnamedField PyPyStructSequence_UnnamedField
 #define PyFunction_Type PyPyFunction_Type
 #define PyMethod_Type PyPyMethod_Type
 #define PyRange_Type PyPyRange_Type
